==> scriptcase-9.5.003-pt_br-php7.3.zip: scriptcase-9.5.003-pt_br-php7.3/prod/lib/php/devel/lang/pt_br/AdminSysAllConectionsCreateWizard.lang.php <==
<?php 
$nm_lang['create_conn_wizard']['btnavancar'] = 'Avan&ccedil;ar'; 
$nm_lang['create_conn_wizard']['btnconcluir'] = 'Concluir'; 
$nm_lang['create_conn_wizard']['btnhelp'] = 'Ajuda'; 
$nm_lang['create_conn_wizard']['btnsair'] = 'Cancelar'; 
$nm_lang['create_conn_wizard']['btntestar'] = 'Testar Conex&atilde;o'; 
$nm_lang['create_conn_wizard']['btnvoltar'] = 'Voltar'; 
$nm_lang['create_conn_wizard']['descricoes']['access'] = 'PATH onde se encontra o arquivo do MS Access!'; 
$nm_lang['create_conn_wizard']['descricoes']['base'] = 'A base de dados no servidor onde encontra-se as suas tabelas!'; 
$nm_lang['create_conn_wizard']['descricoes']['conn'] = '&Eacute; apenas um nome para que voc&ecirc; possa identificar a conex&atilde;o que est&aacute; sendo crianda. Quando voc&ecirc; for criar aplica&ccedil;&otilde;es, ser&aacute; necess&aacute;rio escolher uma conex&atilde;o, &eacute; esse nome que aparecer&aacute; para voc&ecirc; escolher!'; 
$nm_lang['create_conn_wizard']['descricoes']['dbms'] = '&Eacute; o tipo de banco de dados no qual voce est&aacute; tentando se conectar!'; 
$nm_lang['create_conn_wizard']['descricoes']['decimal'] = 'Separador decimal do SGDB. Usado para dar os Insert e Updates nas aplica&ccedil;&otilde;es. <br><br>Ex: UPDATE TB_EXEMPLO SET Salario=1500.00 WHERE CLIENTEID=1 caso voce escolher separador decimal \'.\', <br><br><br>ou UPDATE TB_EXEMPLO SET Salario=\'1500,00\' WHERE CLIENTEID=1 caso voce escolher separador decimal \',\'. <br /><br />Note a diferen&ccedil;a para as aspas!'; 
$nm_lang['create_conn_wizard']['descricoes']['ibase'] = 'Para conectar ao Ibase, o servidor dever&aacute; ser informado o ip da m&aacute;quina, dois ponto, endere&ccedil;o do arquivo. <br /><br />Ex: 192.168.254.254:c:\\ibase\\database.gdb!'; 
$nm_lang['create_conn_wizard']['descricoes']['odbc'] = 'Nome do ODBC que foi criado para acessar ao SGDB!'; 
$nm_lang['create_conn_wizard']['descricoes']['oracle'] = 'Nome do TSNAME de acesso ao SGDB Oracle!'; 
$nm_lang['create_conn_wizard']['descricoes']['pass'] = 'A senha do usu&aacute;rio de acesso ao SGDB!'; 
$nm_lang['create_conn_wizard']['descricoes']['pass_confirm'] = 'A senha de confirma&ccedil;&atilde;o deve ser igual ao campo senha!'; 
$nm_lang['create_conn_wizard']['descricoes']['rep'] = 'Reposit&oacute;rio-DataDicion&aacute;rio &eacute; uma ferramenta para guardar informa&ccedil;&otilde;es sobre seu banco de dados para agilizar a cria&ccedil;&atilde;o de aplica&ccedil;&otilde;es!'; 
$nm_lang['create_conn_wizard']['descricoes']['retrieve_schema'] = 'Escolha se vai usar o nome do schema antes do nome da tabela. Ex: public.nome_da_tabela. <br /><br />Caso n&atilde;o saiba o que significa essa op&ccedil;&atilde;o, deixe o valor default.'; 
$nm_lang['create_conn_wizard']['descricoes']['schema'] = 'O schema no banco de dados onde encontra-se as tabelas!'; 
$nm_lang['create_conn_wizard']['descricoes']['server'] = 'Endere&ccedil;o do servidor onde encotra-se o seu banco de dados. Poder ser localmente ou remotamente. Basta informar o IP ou o nome da m&aacute;quina na rede!'; 
$nm_lang['create_conn_wizard']['descricoes']['sgdb'] = 'M&eacute;todo de acesso ao SGDB. Pode conectar normalmente ou usando alguma vers&atilde;o espec&iacute;fica do banco, ou conectar via ADO ou ODBC!'; 
$nm_lang['create_conn_wizard']['descricoes']['sqlite'] = 'Path onde se encontra o arquivo do SQLite!'; 
$nm_lang['create_conn_wizard']['descricoes']['user'] = 'O nome do usu&aacute;rio de acesso ao SGDB!'; 

$nm_lang['create_conn_wizard']['descricoes']['use_persistent'] = 'Conex&atilde;o persistente, mesmo apos fechar a conex&atilde;o com o banco, ela fica ativa no pool de conex&otilde;es. Ao abrir uma nova conex&atilde;o, ele checa no pool de conex&atilde;o e pega o handle. <br /><br />Normalmente &eacute; mais r&aacute;pida pois n&atilde;o abre de fato uma nova conex&atilde;o. <br /><br />Mas nem todos os bancos de dados s&atilde;o compativeis ou r&aacute;pidos. <br /><br />Alguns bancos tem cache e nesses casos &eacute; melhor abrir uma nova conex&atilde;o limpa.'; 
$nm_lang['create_conn_wizard']['erro']['conn'] = 'Informe um nome de conex&atilde;o v&aacute;lido!'; 
$nm_lang['create_conn_wizard']['erro']['conn_e'] = 'O Nome da Conex&atilde;o informado j&aacute; existe!'; 
$nm_lang['create_conn_wizard']['erro']['pass_confirm'] = 'A senha de confirma&ccedil;&atilde;o est&aacute; diferente da senha!'; 
$nm_lang['create_conn_wizard']['erro']['sgdb'] = 'Informe um SGDB V&aacute;lido!'; 
$nm_lang['create_conn_wizard']['erro']['title'] = 'ERRO'; 
$nm_lang['form_db2_warning'] = 'Aten&ccedil;&atilde;o, as configura&ccedil;&otilde;es abaixo s&atilde;o espec&iacute;ficas do drive nativo ibm_db2. <br />So altere se voc&ecirc; souber o que esta fazendo. Para maiores detalhes consulte: <br />http://br2.php.net/manual/pt_BR/function.db2-connect.php'; 
$nm_lang['label']['access'] = 'PATH'; 
$nm_lang['label']['action'] = 'A&ccedil;&otilde;es'; 
$nm_lang['label']['addgroup'] = 'Adicionar a Conex&atilde;o ao meu Projeto atual!'; 
$nm_lang['label']['base'] = 'Base de Dados'; 
$nm_lang['label']['conn'] = 'Nome da Conex&atilde;o'; 
$nm_lang['label']['dbms'] = 'SGDB'; 
$nm_lang['label']['decimal'] = 'Separador De Decimal'; 
$nm_lang['label']['ibase'] = 'IP:PATH'; 
$nm_lang['label']['lista'] = 'Lista de Conex&otilde;es'; 
$nm_lang['label']['odbc'] = 'Nome do ODBC'; 
$nm_lang['label']['oracle'] = 'Nome do TSNAME'; 
$nm_lang['label']['pass'] = 'Senha'; 
$nm_lang['label']['pass_confirm'] = 'Confirmar Senha'; 
$nm_lang['label']['port']  = 'Port (default %s)';
$nm_lang['label']['prj_criado'] = 'Projeto criado com sucesso, prossiga para criar a conex&atilde;o.'; 
$nm_lang['label']['rep'] = 'Reposit&oacute;rio'; 
$nm_lang['label']['retrieve_schema'] = 'Usar o schema antes do nome da tabela'; 
$nm_lang['label']['schema'] = 'Schema'; 
$nm_lang['label']['server'] = 'Servidor do SGDB'; 
$nm_lang['label']['sgdb'] = 'Modelo do SGDB'; 
$nm_lang['label']['sqlite'] = 'PATH'; 
$nm_lang['label']['testar'] = 'Deseja Testar a conex&atilde;o?'; 
$nm_lang['label']['user'] = 'Usu&aacute;rio'; 
$nm_lang['label']['use_persistent'] = 'Conex&atilde;o Persistente'; 
$nm_lang['lbl_hide_filter'] = 'Ocultar Filtro'; 
$nm_lang['lic_new_error_pr_'] = 'O seu tipo de licen&ccedil;a Professional Edition s&oacute; permite criar 5 conex&otilde;es.<BR>Enter em contato com a NetMake caso queira migrar o tipo de licen&ccedil;a.'; 
$nm_lang['msg_cancel_create_conn'] = 'Deseja cancelar ?'; 
$nm_lang['msg_connect_lang'] = 'Se voc&ecirc; ir&aacute; trabalhar com caracteres multibyte como: &Aacute;rabe, Chin&ecirc;s, Japon&ecirc;s ou Russo, &eacute; imprescind&iacute;vel que o seu banco de dados esteja utilizando codifica&ccedil;&atilde;o UTF-8 pois todos os dados lidos e escritos ser&atilde;o tratados nesta codifica&ccedil;&atilde;o.'; 
$nm_lang['msg_conn_erro']  = 'Connection Error'; 
$nm_lang['msg_empty_lst_conn'] = 'Lista de conex&otilde;es vazia.'; 
$nm_lang['msg_err_server_empty']  = 'Servidor n&atilde;o / Host (nome ou IP), informou!'; 
$nm_lang['msg_err_user_empty'] = 'Usu&aacute;rio n&atilde;o informado !'; 
$nm_lang['new_denied'] = 'Acesso Negado'; 
$nm_lang['page_title'] = 'Clique no &iacute;cone para selecionar o DBMS para conectar-se'; 
$nm_lang['page_title_edit']  = 'Clique no &iacute;cone para selecionar a conex&atilde;o para editar'; 
$nm_lang['page_title_sucess'] = 'Conex&atilde;o Criada Com Sucesso'; 
$nm_lang['values']['nao'] = 'N&atilde;o'; 
$nm_lang['values']['sim'] = 'Sim'; 

$nm_lang['lbl_excl'] = 'Deseja realmente excluir a conex&atilde;o ?';
$nm_lang['mainmenu_new_conn']  = 'Nova conex&atilde;o'; 
$nm_lang['btn_conc'] = 'Salvar'; 
$nm_lang['btn_db2'] = 'DB2'; 
$nm_lang['btn_edit'] = 'Editar'; 
$nm_lang['btn_excl'] = 'Excluir'; 
$nm_lang['btn_filt'] = 'Filtrar'; 
$nm_lang['btn_pass'] = 'Trocar Senha'; 
$nm_lang['btn_stat'] = 'Conex&atilde;o'; 
$nm_lang['btn_test'] = 'Testar'; 
$nm_lang['lbl_apli'] = 'Aplicar'; 
$nm_lang['lbl_atr'] = 'Atributo'; 
$nm_lang['lbl_base'] = 'Base'; 
$nm_lang['lbl_dbms'] = 'Tipo Do Banco'; 
$nm_lang['lbl_deci'] = 'Separador Decimal'; 
$nm_lang['lbl_excl'] = 'Deseja realmente excluir a conex&atilde;o ?'; 
$nm_lang['lbl_exi'] = 'Exibir'; 
$nm_lang['lbl_filt'] = 'Filtros'; 
$nm_lang['lbl_filt_exib'] = 'Exibir'; 
$nm_lang['lbl_filt_n_exib'] = 'N&atilde;o Exibir'; 
$nm_lang['lbl_filt_owner'] = 'Propriet&aacute;rio'; 
$nm_lang['lbl_filt_tab'] = 'Tabelas'; 
$nm_lang['lbl_nao'] = 'N&atilde;o'; 
$nm_lang['lbl_pass'] = 'Senha'; 
$nm_lang['lbl_pass_blank'] = 'Setar senha em branco'; 
$nm_lang['lbl_pass_confirm'] = 'Confirma&ccedil;&atilde;o de Senha'; 
$nm_lang['lbl_retrieve_schema'] = 'Usar o schema antes do nome da tabela'; 
$nm_lang['lbl_schema'] = 'Esquema'; 
$nm_lang['lbl_serv'] = 'Servidor'; 
$nm_lang['lbl_show_proc'] = 'Procedures'; 
$nm_lang['lbl_show_system'] = 'Tabelas de Sistema'; 
$nm_lang['lbl_show_table'] = 'Tabelas'; 
$nm_lang['lbl_show_view'] = 'Views'; 
$nm_lang['lbl_sim'] = 'Sim'; 
$nm_lang['lbl_trans'] = 'Tem Controle de transa&ccedil;&atilde;o?'; 
$nm_lang['lbl_use_persistent'] = 'Conex&atilde;o Persistente'; 
$nm_lang['lbl_usua'] = 'Usu&aacute;rio'; 
$nm_lang['lbl_val'] = 'Valor'; 
$nm_lang['msg_connect_lang'] = 'Se voc&ecirc; ir&aacute; trabalhar com caracteres multibyte como: &Aacute;rabe, Chin&ecirc;s, Japon&ecirc;s ou Russo, &eacute; imprescind&iacute;vel que o seu banco de dados esteja utilizando codifica&ccedil;&atilde;o UTF-8 pois todos os dados lidos e escritos ser&atilde;o tratados nesta codifica&ccedil;&atilde;o.'; 
$nm_lang['msg_save_text'] = 'Modifica&ccedil;&otilde;es salvas na base de dados.'; 
$nm_lang['msg_save_title'] = 'Aviso'; 
$nm_lang['button_cancel'] = 'Cancelar'; 
$nm_lang['button_close'] = 'Fechar'; 
$nm_lang['button_confirm'] = 'Confirmar'; 
$nm_lang['lbl_bt_edit_conn']  = 'Editar conex&atilde;o'; 
$nm_lang['lbl_connection_edit']  = 'Editar conex&atilde;o'; 

$nm_lang['lbl_loading'] = 'Carregando';

$nm_lang['page_apl_cache'] = 'As aplicações publicadas fazem cache de conexão. Ao alterar qualquer dado da conexão, lembre-se de fechar o browser da aplicação gerada e abrir novamente!';

$nm_lang['create_conn_wizard']['descricoes']['date_separator'] = 'Carácter para usar como delimitador nos campos de data no banco de dados. Ex: &#39;2016-01-01&#39; <br /><br />Caso não saiba o que significa essa opção, deixe em branco.';
$nm_lang['label']['date_separator'] = 'Carácter delimitador para data no banco de dados';
$nm_lang['lbl_date_separator'] = $nm_lang['label']['date_separator'];

$nm_lang['label']['use_ssl']          = 'Usar SSL';
$nm_lang['label']['mysql_ssl_key']    = '​​​Chave do cliente';
$nm_lang['label']['mysql_ssl_cert']   = 'Certificado do cliente';
$nm_lang['label']['mysql_ssl_capath'] = 'Caminho CA';
$nm_lang['label']['mysql_ssl_ca']     = 'Certificado CA';
$nm_lang['label']['mysql_ssl_cipher'] = 'Cipher específico';
$nm_lang['grp_conn_available'] = 'Conexões disponíveis';
?>

==> scriptcase-9.13.009-pt_br-php8.1.zip: scriptcase-9.13.009-pt_br-php8.1/prod/lib/php/devel/lang/pt_br/AdminSysAllConectionsCreateWizard.lang.php <==
<?php
$nm_lang['create_conn_wizard']['tabadvanced'] = 'Avan&ccedil;ado';
$nm_lang['create_conn_wizard']['btnavancar'] = 'Avan&ccedil;ar';
$nm_lang['create_conn_wizard']['btnconcluir'] = 'Concluir';
$nm_lang['create_conn_wizard']['btnhelp'] = 'Ajuda';
$nm_lang['create_conn_wizard']['btnsair'] = 'Cancelar';
$nm_lang['create_conn_wizard']['btntestar'] = 'Testar Conex&atilde;o';
$nm_lang['create_conn_wizard']['btnvoltar'] = 'Voltar';
$nm_lang['create_conn_wizard']['descricoes']['access'] = 'PATH onde se encontra o arquivo do MS Access!';
$nm_lang['create_conn_wizard']['descricoes']['base'] = 'A base de dados no servidor onde encontra-se as suas tabelas!';
$nm_lang['create_conn_wizard']['descricoes']['conn'] = '&Eacute; apenas um nome para que voc&ecirc; possa identificar a conex&atilde;o que est&aacute; sendo crianda. Quando voc&ecirc; for criar aplica&ccedil;&otilde;es, ser&aacute; necess&aacute;rio escolher uma conex&atilde;o, &eacute; esse nome que aparecer&aacute; para voc&ecirc; escolher!';
$nm_lang['create_conn_wizard']['descricoes']['dbms'] = '&Eacute; o tipo de banco de dados no qual voce est&aacute; tentando se conectar!';
$nm_lang['create_conn_wizard']['descricoes']['decimal'] = 'Separador decimal do SGDB. Usado para dar os Insert e Updates nas aplica&ccedil;&otilde;es. <br><br>Ex: UPDATE TB_EXEMPLO SET Salario=1500.00 WHERE CLIENTEID=1 caso voce escolher separador decimal \'.\', <br><br><br>ou UPDATE TB_EXEMPLO SET Salario=\'1500,00\' WHERE CLIENTEID=1 caso voce escolher separador decimal \',\'. <br /><br />Note a diferen&ccedil;a para as aspas!';
$nm_lang['create_conn_wizard']['descricoes']['ibase'] = 'Para conectar ao Ibase, o servidor dever&aacute; ser informado o ip da m&aacute;quina, dois ponto, endere&ccedil;o do arquivo. <br /><br />Ex: 192.168.254.254:c:\\ibase\\database.gdb!';
$nm_lang['create_conn_wizard']['descricoes']['odbc'] = 'Nome do ODBC que foi criado para acessar ao SGDB!';
$nm_lang['create_conn_wizard']['descricoes']['oracle'] = 'Nome do TSNAME de acesso ao SGDB Oracle!';
$nm_lang['create_conn_wizard']['descricoes']['pass'] = 'A senha do usu&aacute;rio de acesso ao SGDB!';
$nm_lang['create_conn_wizard']['descricoes']['pass_confirm'] = 'A senha de confirma&ccedil;&atilde;o deve ser igual ao campo senha!';
$nm_lang['create_conn_wizard']['descricoes']['rep'] = 'Reposit&oacute;rio-DataDicion&aacute;rio &eacute; uma ferramenta para guardar informa&ccedil;&otilde;es sobre seu banco de dados para agilizar a cria&ccedil;&atilde;o de aplica&ccedil;&otilde;es!';
$nm_lang['create_conn_wizard']['descricoes']['retrieve_schema'] = 'Escolha se vai usar o nome do schema antes do nome da tabela. Ex: public.nome_da_tabela. <br /><br />Caso n&atilde;o saiba o que significa essa op&ccedil;&atilde;o, deixe o valor default.';
$nm_lang['create_conn_wizard']['descricoes']['schema'] = 'O schema no banco de dados onde encontra-se as tabelas!';
$nm_lang['create_conn_wizard']['descricoes']['server'] = 'Endere&ccedil;o do servidor onde encotra-se o seu banco de dados. Poder ser localmente ou remotamente. Basta informar o IP ou o nome da m&aacute;quina na rede!';
$nm_lang['create_conn_wizard']['descricoes']['sgdb'] = 'M&eacute;todo de acesso ao SGDB. Pode conectar normalmente ou usando alguma vers&atilde;o espec&iacute;fica do banco, ou conectar via ADO ou ODBC!';
$nm_lang['create_conn_wizard']['descricoes']['sqlite'] = 'Path onde se encontra o arquivo do SQLite!';
$nm_lang['create_conn_wizard']['descricoes']['user'] = 'O nome do usu&aacute;rio de acesso ao SGDB!';

$nm_lang['create_conn_wizard']['descricoes']['use_persistent'] = 'Conex&atilde;o persistente, mesmo apos fechar a conex&atilde;o com o banco, ela fica ativa no pool de conex&otilde;es. Ao abrir uma nova conex&atilde;o, ele checa no pool de conex&atilde;o e pega o handle. <br /><br />Normalmente &eacute; mais r&aacute;pida pois n&atilde;o abre de fato uma nova conex&atilde;o. <br /><br />Mas nem todos os bancos de dados s&atilde;o compativeis ou r&aacute;pidos. <br /><br />Alguns bancos tem cache e nesses casos &eacute; melhor abrir uma nova conex&atilde;o limpa.';
$nm_lang['create_conn_wizard']['erro']['conn'] = 'Informe um nome de conex&atilde;o v&aacute;lido!';
$nm_lang['create_conn_wizard']['erro']['conn_e'] = 'O Nome da Conex&atilde;o informado j&aacute; existe!';
$nm_lang['create_conn_wizard']['erro']['pass_confirm'] = 'A senha de confirma&ccedil;&atilde;o est&aacute; diferente da senha!';
$nm_lang['create_conn_wizard']['erro']['sgdb'] = 'Informe um SGDB V&aacute;lido!';
$nm_lang['create_conn_wizard']['erro']['title'] = 'ERRO';
$nm_lang['form_db2_warning'] = 'Aten&ccedil;&atilde;o, as configura&ccedil;&otilde;es abaixo s&atilde;o espec&iacute;ficas do drive nativo ibm_db2. <br />So altere se voc&ecirc; souber o que esta fazendo. Para maiores detalhes consulte: <br />http://br2.php.net/manual/pt_BR/function.db2-connect.php';
$nm_lang['label']['access'] = 'PATH';
$nm_lang['label']['action'] = 'A&ccedil;&otilde;es';
$nm_lang['label']['addgroup'] = 'Adicionar a Conex&atilde;o ao meu Projeto atual!';
$nm_lang['label']['base'] = 'Base de Dados';
$nm_lang['label']['listar_base'] = 'Listar bases';
$nm_lang['label']['conn'] = 'Nome da Conex&atilde;o';
$nm_lang['label']['dbms'] = 'SGDB';
$nm_lang['label']['decimal'] = 'Separador De Decimal';
$nm_lang['label']['ibase'] = 'IP:PATH';
$nm_lang['label']['lista'] = 'Lista de Conex&otilde;es';
$nm_lang['label']['odbc'] = 'Nome do ODBC';
$nm_lang['label']['oracle'] = 'Nome do TSNAME';
$nm_lang['label']['pass'] = 'Senha';
$nm_lang['label']['pass_confirm'] = 'Confirmar Senha';
$nm_lang['label']['port']  = 'Porta';
$nm_lang['label']['prj_criado'] = 'Projeto criado com sucesso, prossiga para criar a conex&atilde;o.';
$nm_lang['label']['rep'] = 'Reposit&oacute;rio';
$nm_lang['label']['retrieve_schema'] = 'Usar o schema antes do nome da tabela';
$nm_lang['label']['schema'] = 'Schema';
$nm_lang['label']['server'] = 'Servidor do SGDB';
$nm_lang['label']['sgdb'] = 'Modelo do SGDB';
$nm_lang['label']['sqlite'] = 'PATH';
$nm_lang['label']['testar'] = 'Deseja Testar a conex&atilde;o?';
$nm_lang['label']['user'] = 'Usu&aacute;rio';
$nm_lang['label']['use_persistent'] = 'Conex&atilde;o Persistente';
$nm_lang['lbl_hide_filter'] = 'Ocultar Filtro';
$nm_lang['lic_new_error_pr_'] = 'O seu tipo de licen&ccedil;a Professional Edition s&oacute; permite criar 5 conex&otilde;es.<BR>Enter em contato com a NetMake caso queira migrar o tipo de licen&ccedil;a.';
$nm_lang['msg_cancel_create_conn'] = 'Deseja cancelar ?';
$nm_lang['msg_connect_lang'] = 'Se voc&ecirc; ir&aacute; trabalhar com caracteres multibyte como: &Aacute;rabe, Chin&ecirc;s, Japon&ecirc;s ou Russo, &eacute; imprescind&iacute;vel que o seu banco de dados esteja utilizando codifica&ccedil;&atilde;o UTF-8 pois todos os dados lidos e escritos ser&atilde;o tratados nesta codifica&ccedil;&atilde;o.';
$nm_lang['msg_conn_erro']  = 'Connection Error';
$nm_lang['msg_empty_lst_conn'] = 'Lista de conex&otilde;es vazia.';
$nm_lang['msg_err_server_empty']  = 'Servidor/Host (Nome ou IP) n&atilde;o informado!';
$nm_lang['msg_err_user_empty'] = 'Usu&aacute;rio n&atilde;o informado !';
$nm_lang['new_denied'] = 'Acesso Negado';
$nm_lang['page_title'] = 'Nova conexão';
$nm_lang['page_title_edit']   = 'Editar conexão';
$nm_lang['page_edit_refresh'] = "Atualizar";
$nm_lang['page_title_sucess'] = 'Conex&atilde;o Criada Com Sucesso';
$nm_lang['values']['nao'] = 'N&atilde;o';
$nm_lang['values']['sim'] = 'Sim';

$nm_lang['lbl_excl'] = 'Deseja realmente excluir a conex&atilde;o ?';
$nm_lang['mainmenu_new_conn']       = 'Nova conex&atilde;o';
$nm_lang['mainmenu_new_conn_tab']   = 'Avançado';
$nm_lang['mainmenu_sec_tab']   = 'Segurança';
$nm_lang['btn_conc'] = 'Salvar';
$nm_lang['btn_db2'] = 'DB2';
$nm_lang['btn_edit'] = 'Editar';
$nm_lang['btn_excl'] = 'Excluir';
$nm_lang['btn_filt'] = 'Filtrar';
$nm_lang['btn_pass'] = 'Trocar Senha';
$nm_lang['btn_stat'] = 'Conex&atilde;o';
$nm_lang['btn_test'] = 'Testar';
$nm_lang['lbl_apli'] = 'Aplicar';
$nm_lang['lbl_atr'] = 'Atributo';
$nm_lang['lbl_base'] = 'Base';
$nm_lang['lbl_dbms'] = 'Tipo Do Banco';
$nm_lang['lbl_deci'] = 'Separador Decimal';
$nm_lang['lbl_excl'] = 'Deseja realmente excluir a conex&atilde;o ?';
$nm_lang['lbl_exi'] = 'Exibir';
$nm_lang['lbl_filt'] = 'Filtros';
$nm_lang['lbl_filt_exib'] = 'Exibir';
$nm_lang['lbl_filt_n_exib'] = 'N&atilde;o Exibir';
$nm_lang['lbl_filt_owner'] = 'Propriet&aacute;rio';
$nm_lang['lbl_filt_tab'] = 'Tabelas';
$nm_lang['lbl_nao'] = 'N&atilde;o';
$nm_lang['lbl_pass'] = 'Senha';
$nm_lang['lbl_pass_blank'] = 'Setar senha em branco';
$nm_lang['lbl_pass_confirm'] = 'Confirma&ccedil;&atilde;o de Senha';
$nm_lang['lbl_retrieve_schema'] = 'Usar o schema antes do nome da tabela';
$nm_lang['lbl_schema'] = 'Esquema';
$nm_lang['lbl_serv'] = 'Servidor';
$nm_lang['lbl_show_proc'] = 'Procedures';
$nm_lang['lbl_show_system'] = 'Tabelas de Sistema';
$nm_lang['lbl_show_table'] = 'Tabelas';
$nm_lang['lbl_show_view'] = 'Views';
$nm_lang['lbl_sim'] = 'Sim';
$nm_lang['lbl_trans'] = 'Tem Controle de transa&ccedil;&atilde;o?';
$nm_lang['lbl_use_persistent'] = 'Conex&atilde;o Persistente';
$nm_lang['lbl_usua'] = 'Usu&aacute;rio';
$nm_lang['lbl_val'] = 'Valor';
$nm_lang['msg_connect_lang'] = 'Se voc&ecirc; ir&aacute; trabalhar com caracteres multibyte como: &Aacute;rabe, Chin&ecirc;s, Japon&ecirc;s ou Russo, &eacute; imprescind&iacute;vel que o seu banco de dados esteja utilizando codifica&ccedil;&atilde;o UTF-8 pois todos os dados lidos e escritos ser&atilde;o tratados nesta codifica&ccedil;&atilde;o.';
$nm_lang['msg_save_text'] = 'Modifica&ccedil;&otilde;es salvas na base de dados.';
$nm_lang['msg_save_title'] = 'Aviso';
$nm_lang['button_cancel'] = 'Cancelar';
$nm_lang['button_close'] = 'Fechar';
$nm_lang['button_confirm'] = 'Confirmar';
$nm_lang['lbl_bt_edit_conn']  = 'Editar conex&atilde;o';
$nm_lang['lbl_connection_edit']  = 'Editar conex&atilde;o';
$nm_lang['unsuccessful_conn']  = 'A conexão falhou, deseja salvar mesmo assim?';

$nm_lang['lbl_loading'] = 'Carregando';

$nm_lang['page_apl_cache'] = 'As aplicações publicadas fazem cache de conexão. Ao alterar qualquer dado da conexão, lembre-se de fechar o browser da aplicação gerada e abrir novamente!';

$nm_lang['create_conn_wizard']['descricoes']['date_separator'] = 'Caractere para usar como delimitador nos campos de data no banco de dados. Ex: &#39;2016-01-01&#39; <br /><br />Caso não saiba o que significa essa opção, deixe em branco.';
$nm_lang['label']['date_separator'] = 'Caractere delimitador para data no banco de dados';
$nm_lang['lbl_date_separator'] = $nm_lang['label']['date_separator'];

$nm_lang['label']['use_ssl']          = 'Usar SSL';
$nm_lang['label']['use_ssh']          = 'Usar SSH';
$nm_lang['label']['mysql_ssl_key']    = 'Chave do cliente';
$nm_lang['label']['mysql_ssl_cert']   = 'Certificado do cliente';
$nm_lang['label']['mysql_ssl_capath'] = 'Caminho CA';
$nm_lang['label']['mysql_ssl_ca']     = 'Certificado CA';
$nm_lang['label']['mysql_ssl_cipher'] = 'Cipher específico';
$nm_lang['grp_conn_available'] = 'Conexões disponíveis';

$nm_lang['label']['ssh_server']              = 'Servidor SSH';
$nm_lang['label']['ssh_user']                = 'usuário SSH';
$nm_lang['label']['ssh_pass']                = 'Senha';
$nm_lang['label']['ssh_port']                = 'Porta SSH';
$nm_lang['label']['ssh_privatecert']         = 'Arquivo do certificado privado';
$nm_lang['label']['ssh_localserver']         = 'Servidor do banco a partir do SSH';
$nm_lang['label']['ssh_localport']           = 'Porta do banco a partir do SSH';
$nm_lang['label']['ssh_localportforwarding'] = 'Porta local para forwarding';
$nm_lang['label']['ssh_use_pass']            = 'Método de autenticação';

$nm_lang['label']['placeholder_sel_base'] = 'Digite ou liste o nome do banco de dados';
?>
